@@ -17,14 +17,13 @@ pub trait Command<P: Protocolize, C: ChannelIndex>: Send + Sync + 'static {
 
 //// Despawn Entity ////
 
-#[derive(Debug)]
 pub(crate) struct DespawnEntity {
     entity: Entity,
 }
 
 impl DespawnEntity {
     pub fn new(entity: &Entity) -> Self {
-        return DespawnEntity { entity: *entity };
+        DespawnEntity { entity: *entity }
     }
 }
 
@@ -36,7 +35,6 @@ impl<P: Protocolize, C: ChannelIndex> Command<P, C> for DespawnEntity {
 
 //// Insert Component ////
 
-#[derive(Debug)]
 pub(crate) struct InsertComponent<P: Protocolize, R: ReplicateSafe<P>> {
     entity: Entity,
     component: R,
@@ -45,11 +43,11 @@ pub(crate) struct InsertComponent<P: Protocolize, R: ReplicateSafe<P>> {
 
 impl<P: Protocolize, R: ReplicateSafe<P>> InsertComponent<P, R> {
     pub fn new(entity: &Entity, component: R) -> Self {
-        return InsertComponent {
+        InsertComponent {
             entity: *entity,
             component,
             phantom_p: PhantomData,
-        };
+        }
     }
 }
 
@@ -63,7 +61,6 @@ impl<P: Protocolize, R: ReplicateSafe<P>, C: ChannelIndex> Command<P, C> for Ins
 
 //// Remove Component ////
 
-#[derive(Debug)]
 pub(crate) struct RemoveComponent<P: Protocolize, R: Replicate<P>> {
     entity: Entity,
     phantom_p: PhantomData<P>,
@@ -72,11 +69,11 @@ pub(crate) struct RemoveComponent<P: Protocolize, R: Replicate<P>> {
 
 impl<P: Protocolize, R: Replicate<P>> RemoveComponent<P, R> {
     pub fn new(entity: &Entity) -> Self {
-        return RemoveComponent {
+        RemoveComponent {
             entity: *entity,
             phantom_p: PhantomData,
             phantom_r: PhantomData,
-        };
+        }
     }
 }
 
