@@ -1,11 +1,13 @@
+use std::default::Default;
+
 use naia_bevy_shared::Flag;
 
 pub struct ServerResource {
     pub ticker: Flag,
 }
 
-impl ServerResource {
-    pub fn new() -> Self {
+impl Default for ServerResource {
+    fn default() -> Self {
         Self {
             ticker: Flag::new(),
         }
